==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/config_config_rule/ConfigConfigRuleSource.java <==
package com.hashicorp.cdktf.providers.aws.config_config_rule;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:52.245Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.configConfigRule.ConfigConfigRuleSource")
@software.amazon.jsii.Jsii.Proxy(ConfigConfigRuleSource.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ConfigConfigRuleSource extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_config_rule#owner ConfigConfigRule#owner}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getOwner();

    /**
     * custom_policy_details block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/config_config_rule#custom_policy_details ConfigConfigRule#custom_policy_details}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails getCustomPolicyDetails() {
        return null;
    }

    /**
     * source_detail block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/config_config_rule#source_detail ConfigConfigRule#source_detail}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getSourceDetail() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_config_rule#source_identifier ConfigConfigRule#source_identifier}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourceIdentifier() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ConfigConfigRuleSource}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ConfigConfigRuleSource}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ConfigConfigRuleSource> {
        java.lang.String owner;
        com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails customPolicyDetails;
        java.lang.Object sourceDetail;
        java.lang.String sourceIdentifier;

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getOwner}
         * @param owner Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_config_rule#owner ConfigConfigRule#owner}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder owner(java.lang.String owner) {
            this.owner = owner;
            return this;
        }

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getCustomPolicyDetails}
         * @param customPolicyDetails custom_policy_details block.
         *                            Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/config_config_rule#custom_policy_details ConfigConfigRule#custom_policy_details}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customPolicyDetails(com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails customPolicyDetails) {
            this.customPolicyDetails = customPolicyDetails;
            return this;
        }

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getSourceDetail}
         * @param sourceDetail source_detail block.
         *                     Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/config_config_rule#source_detail ConfigConfigRule#source_detail}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceDetail(com.hashicorp.cdktf.IResolvable sourceDetail) {
            this.sourceDetail = sourceDetail;
            return this;
        }

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getSourceDetail}
         * @param sourceDetail source_detail block.
         *                     Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/config_config_rule#source_detail ConfigConfigRule#source_detail}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceDetail(java.util.List<? extends com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceSourceDetail> sourceDetail) {
            this.sourceDetail = sourceDetail;
            return this;
        }

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getSourceIdentifier}
         * @param sourceIdentifier Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_config_rule#source_identifier ConfigConfigRule#source_identifier}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceIdentifier(java.lang.String sourceIdentifier) {
            this.sourceIdentifier = sourceIdentifier;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ConfigConfigRuleSource}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ConfigConfigRuleSource build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ConfigConfigRuleSource}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ConfigConfigRuleSource {
        private final java.lang.String owner;
        private final com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails customPolicyDetails;
        private final java.lang.Object sourceDetail;
        private final java.lang.String sourceIdentifier;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.owner = software.amazon.jsii.Kernel.get(this, "owner", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.customPolicyDetails = software.amazon.jsii.Kernel.get(this, "customPolicyDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails.class));
            this.sourceDetail = software.amazon.jsii.Kernel.get(this, "sourceDetail", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.sourceIdentifier = software.amazon.jsii.Kernel.get(this, "sourceIdentifier", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.owner = java.util.Objects.requireNonNull(builder.owner, "owner is required");
            this.customPolicyDetails = builder.customPolicyDetails;
            this.sourceDetail = builder.sourceDetail;
            this.sourceIdentifier = builder.sourceIdentifier;
        }

        @Override
        public final java.lang.String getOwner() {
            return this.owner;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails getCustomPolicyDetails() {
            return this.customPolicyDetails;
        }

        @Override
        public final java.lang.Object getSourceDetail() {
            return this.sourceDetail;
        }

        @Override
        public final java.lang.String getSourceIdentifier() {
            return this.sourceIdentifier;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("owner", om.valueToTree(this.getOwner()));
            if (this.getCustomPolicyDetails() != null) {
                data.set("customPolicyDetails", om.valueToTree(this.getCustomPolicyDetails()));
            }
            if (this.getSourceDetail() != null) {
                data.set("sourceDetail", om.valueToTree(this.getSourceDetail()));
            }
            if (this.getSourceIdentifier() != null) {
                data.set("sourceIdentifier", om.valueToTree(this.getSourceIdentifier()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.configConfigRule.ConfigConfigRuleSource"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ConfigConfigRuleSource.Jsii$Proxy that = (ConfigConfigRuleSource.Jsii$Proxy) o;

            if (!owner.equals(that.owner)) return false;
            if (this.customPolicyDetails != null ? !this.customPolicyDetails.equals(that.customPolicyDetails) : that.customPolicyDetails != null) return false;
            if (this.sourceDetail != null ? !this.sourceDetail.equals(that.sourceDetail) : that.sourceDetail != null) return false;
            return this.sourceIdentifier != null ? this.sourceIdentifier.equals(that.sourceIdentifier) : that.sourceIdentifier == null;
        }

        @Override
        public final int hashCode() {
            int result = this.owner.hashCode();
            result = 31 * result + (this.customPolicyDetails != null ? this.customPolicyDetails.hashCode() : 0);
            result = 31 * result + (this.sourceDetail != null ? this.sourceDetail.hashCode() : 0);
            result = 31 * result + (this.sourceIdentifier != null ? this.sourceIdentifier.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/config_config_rule/ConfigConfigRuleSource.java <==
package com.hashicorp.cdktf.providers.aws.config_config_rule;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:08.037Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.configConfigRule.ConfigConfigRuleSource")
@software.amazon.jsii.Jsii.Proxy(ConfigConfigRuleSource.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ConfigConfigRuleSource extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/config_config_rule#owner ConfigConfigRule#owner}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getOwner();

    /**
     * custom_policy_details block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/config_config_rule#custom_policy_details ConfigConfigRule#custom_policy_details}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails getCustomPolicyDetails() {
        return null;
    }

    /**
     * source_detail block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/config_config_rule#source_detail ConfigConfigRule#source_detail}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getSourceDetail() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/config_config_rule#source_identifier ConfigConfigRule#source_identifier}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourceIdentifier() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ConfigConfigRuleSource}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ConfigConfigRuleSource}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ConfigConfigRuleSource> {
        java.lang.String owner;
        com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails customPolicyDetails;
        java.lang.Object sourceDetail;
        java.lang.String sourceIdentifier;

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getOwner}
         * @param owner Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/config_config_rule#owner ConfigConfigRule#owner}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder owner(java.lang.String owner) {
            this.owner = owner;
            return this;
        }

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getCustomPolicyDetails}
         * @param customPolicyDetails custom_policy_details block.
         *                            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/config_config_rule#custom_policy_details ConfigConfigRule#custom_policy_details}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customPolicyDetails(com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails customPolicyDetails) {
            this.customPolicyDetails = customPolicyDetails;
            return this;
        }

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getSourceDetail}
         * @param sourceDetail source_detail block.
         *                     Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/config_config_rule#source_detail ConfigConfigRule#source_detail}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceDetail(com.hashicorp.cdktf.IResolvable sourceDetail) {
            this.sourceDetail = sourceDetail;
            return this;
        }

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getSourceDetail}
         * @param sourceDetail source_detail block.
         *                     Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/config_config_rule#source_detail ConfigConfigRule#source_detail}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceDetail(java.util.List<? extends com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceSourceDetail> sourceDetail) {
            this.sourceDetail = sourceDetail;
            return this;
        }

        /**
         * Sets the value of {@link ConfigConfigRuleSource#getSourceIdentifier}
         * @param sourceIdentifier Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/config_config_rule#source_identifier ConfigConfigRule#source_identifier}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceIdentifier(java.lang.String sourceIdentifier) {
            this.sourceIdentifier = sourceIdentifier;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ConfigConfigRuleSource}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ConfigConfigRuleSource build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ConfigConfigRuleSource}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ConfigConfigRuleSource {
        private final java.lang.String owner;
        private final com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails customPolicyDetails;
        private final java.lang.Object sourceDetail;
        private final java.lang.String sourceIdentifier;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.owner = software.amazon.jsii.Kernel.get(this, "owner", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.customPolicyDetails = software.amazon.jsii.Kernel.get(this, "customPolicyDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails.class));
            this.sourceDetail = software.amazon.jsii.Kernel.get(this, "sourceDetail", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.sourceIdentifier = software.amazon.jsii.Kernel.get(this, "sourceIdentifier", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.owner = java.util.Objects.requireNonNull(builder.owner, "owner is required");
            this.customPolicyDetails = builder.customPolicyDetails;
            this.sourceDetail = builder.sourceDetail;
            this.sourceIdentifier = builder.sourceIdentifier;
        }

        @Override
        public final java.lang.String getOwner() {
            return this.owner;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.config_config_rule.ConfigConfigRuleSourceCustomPolicyDetails getCustomPolicyDetails() {
            return this.customPolicyDetails;
        }

        @Override
        public final java.lang.Object getSourceDetail() {
            return this.sourceDetail;
        }

        @Override
        public final java.lang.String getSourceIdentifier() {
            return this.sourceIdentifier;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("owner", om.valueToTree(this.getOwner()));
            if (this.getCustomPolicyDetails() != null) {
                data.set("customPolicyDetails", om.valueToTree(this.getCustomPolicyDetails()));
            }
            if (this.getSourceDetail() != null) {
                data.set("sourceDetail", om.valueToTree(this.getSourceDetail()));
            }
            if (this.getSourceIdentifier() != null) {
                data.set("sourceIdentifier", om.valueToTree(this.getSourceIdentifier()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.configConfigRule.ConfigConfigRuleSource"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ConfigConfigRuleSource.Jsii$Proxy that = (ConfigConfigRuleSource.Jsii$Proxy) o;

            if (!owner.equals(that.owner)) return false;
            if (this.customPolicyDetails != null ? !this.customPolicyDetails.equals(that.customPolicyDetails) : that.customPolicyDetails != null) return false;
            if (this.sourceDetail != null ? !this.sourceDetail.equals(that.sourceDetail) : that.sourceDetail != null) return false;
            return this.sourceIdentifier != null ? this.sourceIdentifier.equals(that.sourceIdentifier) : that.sourceIdentifier == null;
        }

        @Override
        public final int hashCode() {
            int result = this.owner.hashCode();
            result = 31 * result + (this.customPolicyDetails != null ? this.customPolicyDetails.hashCode() : 0);
            result = 31 * result + (this.sourceDetail != null ? this.sourceDetail.hashCode() : 0);
            result = 31 * result + (this.sourceIdentifier != null ? this.sourceIdentifier.hashCode() : 0);
            return result;
        }
    }
}
